@@ -1,11 +1,11 @@
-package Pcore v0.12.4;
+package Pcore v0.13.0;
 
 use v5.22.0;
 use utf8;
 use strict;
 use warnings ( qw[all], FATAL => qw[utf8], NONFATAL => qw[] );
 no if $^V ge 'v5.18', warnings => 'experimental';
-use warnings ( qw[experimental::autoderef], FATAL => qw[experimental::autoderef], NONFATAL => qw[] );
+use if $^V lt 'v5.23', warnings => 'experimental::autoderef', FATAL => 'experimental::autoderef';
 use if $^V ge 'v5.10', feature => ':all';
 no  if $^V ge 'v5.16', feature => 'array_base';
 use if $^V ge 'v5.22', re      => 'strict';
@@ -34,19 +34,19 @@ use AnyEvent;
 
 # define global variables
 BEGIN {
-    $Pcore::INITIALISED      = 0;                         # core initialisation flag
-    $Pcore::CALLER           = caller;                    # namespace, from P was required first time
-    $Pcore::EMBEDDED         = 0;                         # Pcore::Core used in embedded mode
-    $Pcore::IS_PAR           = $ENV{PAR_TEMP} ? 1 : 0;    # process runned from PAR
-    $Pcore::ENCODING_CONSOLE = 'UTF-8';                   # default console encoding, redefined later for windows
-    $Pcore::NO_ISA_ATTR      = 0;                         # do not check isa for class / role attributes
+    $Pcore::INITIALISED = 0;         # core initialisation flag
+    $Pcore::CALLER      = caller;    # namespace, from P was required first time
+    $Pcore::EMBEDDED    = 0;         # Pcore::Core used in embedded mode
+    $Pcore::NO_ISA_ATTR = 0;         # do not check isa for class / role attributes
+    $Pcore::WIN_ENC     = undef;
+    $Pcore::CON_ENC     = undef;
 
     # NOTE workaround for incompatibility with Moo lazy attributes
     # https://rt.cpan.org/Ticket/Display.html?id=102788
     eval {
         local $SIG{__DIE__} = undef;
 
-        require Filter::Crypto::Decrypt if $Pcore::IS_PAR;
+        require Filter::Crypto::Decrypt if $ENV{PAR_TEMP};
     };
 
     # define %EXPORT_PRAGMAS for exporter
@@ -56,7 +56,6 @@ BEGIN {
         export      => 0,    # install standart import method
         no_isa_attr => 0,    # do not check isa for class / role attributes
         autoload    => 0,    # export AUTOLOAD
-        cli         => 0,    # add package namespace to CLI processors stack
         no_clean    => 0,    # do not perform namespace autoclean
         class       => 0,    # package is a Moo class
         role        => 0,    # package is a Moo role
@@ -66,34 +65,32 @@ BEGIN {
 
     # configure standard library
     $Pcore::UTIL = {
-        bit       => 'Pcore::Util::Bit',
-        capture   => 'Pcore::Util::Capture',
-        cfg       => 'Pcore::Util::Config',
-        class     => 'Pcore::Util::Class',
-        data      => 'Pcore::Util::Data',
-        date      => 'Pcore::Util::Date',
-        digest    => 'Pcore::Util::Digest',
-        file      => 'Pcore::Util::File',
-        geoip     => 'Pcore::Util::GeoIP',
-        hash      => 'Pcore::Util::Hash',
-        host      => 'Pcore::Util::URI::Host',
-        list      => 'Pcore::Util::List',
-        mail      => 'Pcore::Util::Mail',
-        moo       => 'Pcore::Util::Moo',
-        path      => 'Pcore::Util::Path',
-        pm        => 'Pcore::Util::PM',
-        progress  => 'Pcore::Util::Progress',
-        prompt    => 'Pcore::Util::Prompt',
-        random    => 'Pcore::Util::Random',
-        res       => 'Pcore::Util::Resources',
-        scalar    => 'Pcore::Util::Scalar',
-        share_dir => 'Pcore::Util::ShareDir',
-        sys       => 'Pcore::Util::Sys',
-        text      => 'Pcore::Util::Text',
-        tmpl      => 'Pcore::Util::Template',
-        ua        => 'Pcore::HTTP::UA',
-        uri       => 'Pcore::Util::URI',
-        uuid      => 'Pcore::Util::UUID',
+        bit      => 'Pcore::Util::Bit',
+        capture  => 'Pcore::Util::Capture',
+        cfg      => 'Pcore::Util::Config',
+        class    => 'Pcore::Util::Class',
+        data     => 'Pcore::Util::Data',
+        date     => 'Pcore::Util::Date',
+        digest   => 'Pcore::Util::Digest',
+        file     => 'Pcore::Util::File',
+        geoip    => 'Pcore::Util::GeoIP',
+        hash     => 'Pcore::Util::Hash',
+        host     => 'Pcore::Util::URI::Host',
+        list     => 'Pcore::Util::List',
+        mail     => 'Pcore::Util::Mail',
+        moo      => 'Pcore::Util::Moo',
+        path     => 'Pcore::Util::Path',
+        pm       => 'Pcore::Util::PM',
+        progress => 'Pcore::Util::Term::Progress',
+        random   => 'Pcore::Util::Random',
+        scalar   => 'Pcore::Util::Scalar',
+        sys      => 'Pcore::Util::Sys',
+        term     => 'Pcore::Util::Term',
+        text     => 'Pcore::Util::Text',
+        tmpl     => 'Pcore::Util::Template',
+        ua       => 'Pcore::HTTP::UA',
+        uri      => 'Pcore::Util::URI',
+        uuid     => 'Pcore::Util::UUID',
     };
 }
 
@@ -121,7 +118,7 @@ sub import {
     strict->import();
     warnings->import( 'all', FATAL => qw[utf8], NONFATAL => qw[] );
     warnings->unimport('experimental') if $^V ge 'v5.18';
-    warnings->import( 'experimental::autoderef', FATAL => qw[experimental::autoderef], NONFATAL => qw[] );
+    warnings->import( 'experimental::autoderef', FATAL => qw[experimental::autoderef] ) if $^V lt 'v5.23';
     feature->import(':all')         if $^V ge 'v5.10';
     feature->unimport('array_base') if $^V ge 'v5.16';
     re->import('strict')            if $^V ge 'v5.22';
@@ -151,7 +148,7 @@ sub import {
     }
 
     # export Pcore::Core
-    Pcore::Core::Constants->import( -caller => $caller, $tags->@* );
+    Pcore::Core::Const->import( -caller => $caller, $tags->@* );
     Pcore::Core::Dump->import( -caller => $caller, $tags->@* );
     Pcore::Core::Exception->import( -caller => $caller, $tags->@* );
     Pcore::Core::H->import( -caller => $caller, $tags->@* );
@@ -215,7 +212,7 @@ sub import {
             # reconfigure warnings, after Moo exported
             warnings->import( 'all', FATAL => qw[utf8], NONFATAL => qw[] );
             warnings->unimport('experimental');
-            warnings->import( 'experimental::autoderef', FATAL => qw[experimental::autoderef], NONFATAL => qw[] );
+            warnings->import( 'experimental::autoderef', FATAL => qw[experimental::autoderef] ) if $^V lt 'v5.23';
 
             # apply default roles
             # $self->_apply_roles( caller => $caller, roles => [qw[Pcore::Core::Autoload::Role]] );
@@ -380,7 +377,7 @@ sub _apply_roles {
 }
 
 # CORE compilation phase
-use Pcore::Core::Constants qw[:CORE];
+use Pcore::Core::Const qw[:CORE];
 use Pcore::Core::EV qw[:CORE];
 use Pcore::Core::Bootstrap qw[];
 use Pcore::Core::Dump qw[:CORE];
@@ -388,7 +385,6 @@ use Pcore::Core::Exception qw[];
 use Pcore::Core::H qw[];
 use Pcore::Core::Log qw[:CORE];
 use Pcore::Core::I18N qw[:CORE];
-use Pcore::Core::CLI qw[];
 
 sub _CORE_INIT ($proc_cfg) {
 
@@ -396,37 +392,77 @@ sub _CORE_INIT ($proc_cfg) {
     $PerlIO::encoding::fallback = Encode::FB_CROAK | Encode::STOP_AT_PARTIAL;
 
     if ($MSWIN) {
-        require Win32::API;
+        require Win32;
         require Win32::Console::ANSI;
 
-        # detect windows active codepage
-        $Pcore::ENCODING_CONSOLE = 'cp' . Win32::API::More->new( 'kernel32', 'int GetACP()' )->Call;
+        $Pcore::WIN_ENC = 'cp' . Win32::GetACP();
+        $Pcore::CON_ENC = Win32::GetConsoleCP();
 
-        # check if we can properly decode STDIN under MSWIN
-        eval {
-            Encode::perlio_ok($Pcore::ENCODING_CONSOLE) or die;
-            1;
-        } || do {
-            say qq[FATAL: Console input encoding "$Pcore::ENCODING_CONSOLE" isn't supported. Use chcp to change console codepage.];
+        if ($Pcore::CON_ENC) {
+            $Pcore::CON_ENC = 'cp' . $Pcore::CON_ENC;
 
-            exit 1;
-        };
+            # check if we can properly decode STDIN under MSWIN
+            eval {
+                Encode::perlio_ok($Pcore::CON_ENC) or die;
+
+                1;
+            } || do {
+                say qq[FATAL: Console input encoding "$Pcore::CON_ENC" isn't supported. Use chcp to change console codepage.];
+
+                exit 1;
+            };
+        }
+        else {
+            $Pcore::CON_ENC = undef;
+        }
+    }
+    else {
+        $Pcore::CON_ENC = 'UTF-8';
+        $Pcore::WIN_ENC = 'UTF-8';
     }
 
     # decode @ARGV
     for (@ARGV) {
-        $_ = Encode::decode( $Pcore::ENCODING_CONSOLE, $_, Encode::FB_CROAK );
+        $_ = Encode::decode( $Pcore::WIN_ENC, $_, Encode::FB_CROAK );
     }
 
     # configure run-time environment
     Pcore::Core::Bootstrap::CORE_INIT($proc_cfg);
 
-    _configure_console();
+    # STDIN
+    if ( -t *STDIN ) {    ## no critic qw[InputOutput::ProhibitInteractiveTest]
+        if ($MSWIN) {
+            binmode *STDIN, ":raw:crlf:encoding($Pcore::CON_ENC)" or die;
+        }
+        else {
+            binmode *STDIN, ':raw:encoding(UTF-8)' or die;
+        }
+    }
+    else {
+        binmode *STDIN, ':raw' or die;
+    }
 
-    Pcore::Core::Log::CORE_INIT();          # set default log pipes
-    Pcore::Core::Exception::CORE_INIT();    # set $SIG{__DIE__}, $SIG{__WARN__}, $SIG->{INT}, $SIG->{TERM} handlers
-    Pcore::Core::I18N::CORE_INIT();         # configure default I18N locations
-    Pcore::Core::CLI::CORE_INIT();          # register CORE::CLI event
+    # STDOUT
+    open our $STDOUT_UTF8, '>&STDOUT' or $STDOUT_UTF8 = *STDOUT;    ## no critic qw[InputOutput::ProhibitBarewordFileHandles]
+
+    _config_stdout($STDOUT_UTF8);
+
+    # STDERR
+    open our $STDERR_UTF8, '>&STDERR' or $STDERR_UTF8 = *STDERR;    ## no critic qw[InputOutput::ProhibitBarewordFileHandles]
+
+    _config_stdout($STDERR_UTF8);
+
+    select $STDOUT_UTF8;                                            ## no critic qw[InputOutput::ProhibitOneArgSelect]
+
+    STDOUT->autoflush(1);
+    STDERR->autoflush(1);
+
+    $STDOUT_UTF8->autoflush(1);
+    $STDERR_UTF8->autoflush(1);
+
+    Pcore::Core::Log::CORE_INIT();                                  # set default log pipes
+    Pcore::Core::Exception::CORE_INIT();                            # set $SIG{__DIE__}, $SIG{__WARN__}, $SIG->{INT}, $SIG->{TERM} handlers
+    Pcore::Core::I18N::CORE_INIT();                                 # configure default I18N locations
 
     return;
 }
@@ -440,8 +476,9 @@ sub _CORE_RUN {
 
     if ( !$Pcore::EMBEDDED ) {
 
-        # throw CORE#CLI event, CLI parsing and processing
-        Pcore->EV->throw('CORE#CLI');
+        require Pcore::Core::CLI;
+
+        Pcore::Core::CLI->new( { class => 'main' } )->run( \@ARGV );
 
         # throw CORE#RUN event to perform daemonize, depends on CLI param
         Pcore->EV->throw('CORE#RUN');
@@ -509,41 +546,27 @@ sub cv {
     return $cv;
 }
 
-sub _configure_console {
-
-    # clone handles
-    open our $STDIN,  '<&STDIN'  or $STDIN  = *STDIN;     ## no critic qw[InputOutput::ProhibitBarewordFileHandles Variables::RequireLocalizedPunctuationVars]
-    open our $STDOUT, '>&STDOUT' or $STDOUT = *STDOUT;    ## no critic qw[InputOutput::ProhibitBarewordFileHandles Variables::RequireLocalizedPunctuationVars]
-    open our $STDERR, '>&STDERR' or $STDERR = *STDERR;    ## no critic qw[InputOutput::ProhibitBarewordFileHandles Variables::RequireLocalizedPunctuationVars]
-
-    # setup default layers for STD* handles
-    binmode STDIN,  q[:raw:encoding(UTF-8)] or die;
-    binmode STDOUT, q[:raw:encoding(UTF-8)] or die;
-    binmode STDERR, q[:raw:encoding(UTF-8)] or die;
-
-    # setup default layers for STD* handles clones
+# TODO add PerlIO::removeEsc layer
+sub _config_stdout ($h) {
     if ($MSWIN) {
-        require Pcore::Core::PerlIOviaWin32UnicodeConsole;
+        if ( -t $h ) {    ## no critic qw[InputOutput::ProhibitInteractiveTest]
+            require Pcore::Core::PerlIOviaWinUniCon;
 
-        binmode $STDIN,  qq[:raw:crlf:encoding($Pcore::ENCODING_CONSOLE)]       or die;
-        binmode $STDOUT, q[:raw:via(Pcore::Core::PerlIOviaWin32UnicodeConsole)] or die;
-        binmode $STDERR, q[:raw:via(Pcore::Core::PerlIOviaWin32UnicodeConsole)] or die;
-
-        select $STDOUT;    ## no critic qw[InputOutput::ProhibitOneArgSelect]
+            binmode $h, ':raw:via(Pcore::Core::PerlIOviaWinUniCon)' or die;    # terminal
+        }
+        else {
+            binmode $h, ':raw:encoding(UTF-8)' or die;                         # file TODO +RemoveESC
+        }
     }
     else {
-        binmode $STDIN,  q[:raw:encoding(UTF-8)] or die;
-        binmode $STDOUT, q[:raw:encoding(UTF-8)] or die;
-        binmode $STDERR, q[:raw:encoding(UTF-8)] or die;
+        if ( -t $h ) {                                                         ## no critic qw[InputOutput::ProhibitInteractiveTest]
+            binmode $h, ':raw:encoding(UTF-8)' or die;                         # terminal
+        }
+        else {
+            binmode $h, ':raw:encoding(UTF-8)' or die;                         # file TODO +RemoveESC
+        }
     }
 
-    # make STD* non-caching
-    STDOUT->autoflush(1);
-    STDERR->autoflush(1);
-
-    $STDOUT->autoflush(1);
-    $STDERR->autoflush(1);
-
     return;
 }
 
@@ -556,19 +579,19 @@ sub _configure_console {
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
 ## │    3 │ 46                   │ ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 103                  │ Subroutines::ProhibitExcessComplexity - Subroutine "import" with high complexity score (26)                    │
+## │    3 │ 100                  │ Subroutines::ProhibitExcessComplexity - Subroutine "import" with high complexity score (28)                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 167                  │ Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               │
+## │    3 │ 164                  │ Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 362                  │ Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_apply_roles' declared but not used │
+## │    3 │ 359                  │ Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_apply_roles' declared but not used │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 407, 455, 472, 520,  │ ErrorHandling::RequireCarping - "die" used instead of "croak"                                                  │
-## │      │ 521, 522, 528, 529,  │                                                                                                                │
-## │      │ 530, 535, 536, 537   │                                                                                                                │
+## │    3 │ 406, 435, 438, 442,  │ ErrorHandling::RequireCarping - "die" used instead of "croak"                                                  │
+## │      │ 492, 509, 555, 558,  │                                                                                                                │
+## │      │ 563, 566             │                                                                                                                │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
 ## │    1 │ 410                  │ InputOutput::RequireCheckedSyscalls - Return value of flagged function ignored - say                           │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 498                  │ CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              │
+## │    1 │ 535                  │ CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
@@ -601,15 +624,7 @@ Documentation will be provided later.
 
 =item * PCORE_DIST_LIB
 
-=item * PCORE_RESOURCES
-
-=item * PCORE_MOUNTED_RESOURCES
-
-=item * MODULE_SIGNATURE_AUTHOR = q["<author-email>"]
-
-=item * __PCORE_SCRIPT_DIR
-
-=item * __PCORE_SCRIPT_NAME
+=item * PCORE_RES_LIB
 
 =back
 
