@@ -1,10 +1,9 @@
 package Pcore::HTTP::Request;
 
-use Pcore qw[-class];
+use Pcore qw[-class -const];
 use Pcore::HTTP::UA;
 use Pcore::HTTP::Response;
 use Pcore::HTTP::CookieJar;
-use Const::Fast;
 
 extends qw[Pcore::HTTP::Message];
 
@@ -21,17 +20,21 @@ const our $HTTP_METHODS => {
 };
 
 has blocking => ( is => 'ro', isa => Bool | InstanceOf ['AnyEvent::CondVar'] );
-has method => ( is => 'ro', isa => Enum [ keys $HTTP_METHODS ], required => 1 );
+has method => ( is => 'ro', isa => Enum [ keys $HTTP_METHODS->%* ], required => 1 );
 has url => ( is => 'ro', isa => Str, required => 1 );
 
 has recurse    => ( is => 'ro', isa => PositiveOrZeroInt );
 has timeout    => ( is => 'ro', isa => PositiveOrZeroInt );
 has persistent => ( is => 'ro', isa => Bool );
-has keepalive  => ( is => 'ro', isa => Bool );
 has session    => ( is => 'ro', isa => Str );
 has cookie_jar => ( is => 'ro', isa => Ref );
 has tls_ctx    => ( is => 'ro', isa => Maybe [ Enum [ $Pcore::HTTP::UA::TLS_CTX_LOW, $Pcore::HTTP::UA::TLS_CTX_HIGH ] | HashRef ] );
 
+has handle_params => ( is => 'ro', isa => HashRef );
+
+has accept_compressed => ( is => 'ro', default => 1 );
+has decompress        => ( is => 'ro', default => 1 );
+
 has proxy => ( is => 'ro', writer => 'set_proxy', predicate => 1, clearer => 1 );
 
 has on_header   => ( is => 'ro', isa => CodeRef );
@@ -93,7 +96,7 @@ sub _get_progress_bar_cb ( $self, %args ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 48                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 23, 51               │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
