@@ -2,9 +2,18 @@ package Pcore::Src::Filter;
 
 use Pcore qw[-role];
 
+has file => ( is => 'ro', isa => InstanceOf ['Pcore::Src::File'], required => 1, weak_ref => 1 );
 has buffer    => ( is => 'ro',   isa => ScalarRef, required => 1 );
 has has_kolon => ( is => 'lazy', isa => Bool,      init_arg => undef );
 
+sub src_cfg ($self) {
+    return Pcore::Src::File->cfg;
+}
+
+sub dist_cfg ($self) {
+    return $self->file->dist_cfg;
+}
+
 sub decompress {
     my $self = shift;
 
@@ -39,4 +48,12 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::Src::Filter
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =cut
