@@ -155,13 +155,15 @@ sub compress ( $self, % ) {
 
     require BerkeleyDB;
 
-    state $cache;
+    state $cache = do {
+        my $path = $PROC->{SYS_TEMP_DIR} . '.pcore/perl-compress.bdb';
 
-    if ( !$cache ) {
-        tie my %cache, 'BerkeleyDB::Hash', -Filename => $PROC->{SYS_TEMP_DIR} . 'perl_compress.bdb', -Flags => BerkeleyDB::DB_CREATE();
+        P->file->mkpath( $PROC->{SYS_TEMP_DIR} . '.pcore/' );
 
-        $cache = \%cache;
-    }
+        tie my %cache, 'BerkeleyDB::Hash', -Filename => $path, -Flags => BerkeleyDB::DB_CREATE();
+
+        \%cache;
+    };
 
     # cut __END__ or __DATA__ sections
     my $data_section = q[];
@@ -363,9 +365,9 @@ sub cut_log ($self) {
 ## │    3 │ 8                    │ Subroutines::ProhibitExcessComplexity - Subroutine "decompress" with high complexity score (24)                │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
 ## │    3 │ 110, 113, 117, 124,  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
-## │      │ 240, 276             │                                                                                                                │
+## │      │ 242, 278             │                                                                                                                │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 161                  │ Miscellanea::ProhibitTies - Tied variable used                                                                 │
+## │    2 │ 163                  │ Miscellanea::ProhibitTies - Tied variable used                                                                 │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
 ## │    1 │ 110                  │ BuiltinFunctions::ProhibitReverseSortBlock - Forbid $b before $a in sort blocks                                │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
