@@ -18,9 +18,73 @@ our $GEOIP_CITY_CACHE_MODE    = $GEOIP_INDEX_CACHE;
 
 my $H;
 
+sub country2_path ( $self, $force = undef, $cv = undef ) {
+    state $path = do {
+        my $_path = $PROC->res->get('/data/geoip2_country.dat');
+
+        if ( !$_path || $force ) {
+            P->ua->request(
+                'http://geolite.maxmind.com/download/geoip/database/GeoLite2-Country.mmdb.gz',
+                buf_size    => 1,
+                on_progress => $cv ? 1 : 0,
+                blocking => $cv || 1,
+                on_finish => sub ($res) {
+                    require IO::Uncompress::Gunzip;
+
+                    if ( $res->status == 200 ) {
+                        my $temp = P->file->tempfile;
+
+                        IO::Uncompress::Gunzip::gunzip( $res->body, $temp->path, BinModeOut => 1 );
+
+                        $_path = $PROC->res->store( $temp->path, '/data/geoip2_country.dat', 'pcore' );
+                    }
+
+                    return;
+                }
+            );
+        }
+
+        $_path;
+    };
+
+    return $path;
+}
+
+sub city2_path ( $self, $force = undef, $cv = undef ) {
+    state $path = do {
+        my $_path = $PROC->res->get('/data/geoip2_city.dat');
+
+        if ( !$_path || $force ) {
+            P->ua->request(
+                'http://geolite.maxmind.com/download/geoip/database/GeoLite2-City.mmdb.gz',
+                buf_size    => 1,
+                on_progress => $cv ? 1 : 0,
+                blocking => $cv || 1,
+                on_finish => sub ($res) {
+                    require IO::Uncompress::Gunzip;
+
+                    if ( $res->status == 200 ) {
+                        my $temp = P->file->tempfile;
+
+                        IO::Uncompress::Gunzip::gunzip( $res->body, $temp->path, BinModeOut => 1 );
+
+                        $_path = $PROC->res->store( $temp->path, '/data/geoip2_city.dat', 'pcore' );
+                    }
+
+                    return;
+                }
+            );
+        }
+
+        $_path;
+    };
+
+    return $path;
+}
+
 sub country_path ( $self, $force = undef, $cv = undef ) {
     state $path = do {
-        my $_path = P->res->get_local('geoip_country.dat');
+        my $_path = $PROC->res->get('/data/geoip_country.dat');
 
         if ( !$_path || $force ) {
             P->ua->request(
@@ -32,11 +96,11 @@ sub country_path ( $self, $force = undef, $cv = undef ) {
                     require IO::Uncompress::Gunzip;
 
                     if ( $res->status == 200 ) {
-                        my $temp = P->file->tempfile( autoflush => 1 );
+                        my $temp = P->file->tempfile;
 
                         IO::Uncompress::Gunzip::gunzip( $res->body, $temp->path, BinModeOut => 1 );
 
-                        $_path = P->res->store_local( 'geoip_country.dat', $temp->path );
+                        $_path = $PROC->res->store( $temp->path, '/data/geoip_country.dat', 'pcore' );
                     }
 
                     return;
@@ -52,7 +116,7 @@ sub country_path ( $self, $force = undef, $cv = undef ) {
 
 sub country_v6_path ( $self, $force = undef, $cv = undef ) {
     state $path = do {
-        my $_path = P->res->get_local('geoip_country_v6.dat');
+        my $_path = $PROC->res->get('/data/geoip_country_v6.dat');
 
         if ( !$_path || $force ) {
             P->ua->request(
@@ -64,11 +128,11 @@ sub country_v6_path ( $self, $force = undef, $cv = undef ) {
                     require IO::Uncompress::Gunzip;
 
                     if ( $res->status == 200 ) {
-                        my $temp = P->file->tempfile( autoflush => 1 );
+                        my $temp = P->file->tempfile;
 
                         IO::Uncompress::Gunzip::gunzip( $res->body, $temp, BinModeOut => 1 );
 
-                        $_path = P->res->store_local( 'geoip_country_v6.dat', $temp->path );
+                        $_path = $PROC->res->store( $temp->path, '/data/geoip_country_v6.dat', 'pcore' );
                     }
 
                     return;
@@ -84,7 +148,7 @@ sub country_v6_path ( $self, $force = undef, $cv = undef ) {
 
 sub city_path ( $self, $force = undef, $cv = undef ) {
     state $path = do {
-        my $_path = P->res->get_local('geoip_city.dat');
+        my $_path = $PROC->res->get('/data/geoip_city.dat');
 
         if ( !$_path || $force ) {
             P->ua->request(
@@ -96,11 +160,11 @@ sub city_path ( $self, $force = undef, $cv = undef ) {
                     require IO::Uncompress::Gunzip;
 
                     if ( $res->status == 200 ) {
-                        my $temp = P->file->tempfile( autoflush => 1 );
+                        my $temp = P->file->tempfile;
 
                         IO::Uncompress::Gunzip::gunzip( $res->body, $temp->path, BinModeOut => 1 );
 
-                        $_path = P->res->store_local( 'geoip_city.dat', $temp->path );
+                        $_path = $PROC->res->store( $temp->path, '/data/geoip_city.dat', 'pcore' );
                     }
 
                     return;
@@ -116,7 +180,7 @@ sub city_path ( $self, $force = undef, $cv = undef ) {
 
 sub city_v6_path ( $self, $force = undef, $cv = undef ) {
     state $path = do {
-        my $_path = P->res->get_local('geoip_city_v6.dat');
+        my $_path = $PROC->res->get('/data/geoip_city_v6.dat');
 
         if ( !$_path || $force ) {
             P->ua->request(
@@ -128,11 +192,11 @@ sub city_v6_path ( $self, $force = undef, $cv = undef ) {
                     require IO::Uncompress::Gunzip;
 
                     if ( $res->status == 200 ) {
-                        my $temp = P->file->tempfile( autoflush => 1 );
+                        my $temp = P->file->tempfile;
 
                         IO::Uncompress::Gunzip::gunzip( $res->body, $temp->path, BinModeOut => 1 );
 
-                        $_path = P->res->store_local( 'geoip_city_v6.dat', $temp->path );
+                        $_path = $PROC->res->store( $temp->path, '/data/geoip_city_v6.dat', 'pcore' );
                     }
 
                     return;
@@ -215,6 +279,10 @@ sub update ($self) {
 
     my $cv = AE::cv;
 
+    $self->country2_path( 1, $cv );
+
+    $self->city2_path( 1, $cv );
+
     $self->country_path( 1, $cv );
 
     $self->country_v6_path( 1, $cv );
@@ -256,3 +324,22 @@ sub record_by_name {
 
 1;
 __END__
+=pod
+
+=encoding utf8
+
+=head1 NAME
+
+Pcore::Util::GeoIP - Maxmind GeoIP wrapper
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+=head1 ATTRIBUTES
+
+=head1 METHODS
+
+=head1 SEE ALSO
+
+=cut
